@@ -213,11 +213,7 @@ class DogeClient(Repr):
                                 return True
                             return False
 
-                        prefixes = []
-                        if isinstance(self.prefix, str):
-                            prefixes.append(self.prefix)
-                        else:
-                            prefixes = self.prefix
+                        prefixes = [self.prefix] if isinstance(self.prefix, str) else self.prefix
 
                         for prefix in prefixes:
                             if await handle_command(prefix):
@@ -439,25 +435,25 @@ class DogeClient(Repr):
             raise NoConnectionException("No room has been joined yet.")
         await self.__send("ask_to_speak", {})
 
-    async def make_mod(self, user: Union[User, BaseUser, UserPreview]):
+    async def make_mod(self, user: Union[str, User, BaseUser, UserPreview]):
         """
         Make a user in the room moderator.
 
         Args:
             user (Union[User, BaseUser, UserPreview]): The user which should be promoted to room moderator.
         """
-        await self.__send("change_mod_status", dict(userId=user.id, value=True))
+        await self.__send("change_mod_status", dict(userId=user if isinstance(user, str) else user.id, value=True))
 
-    async def unmod(self, user: Union[User, BaseUser, UserPreview]):
+    async def unmod(self, user: Union[str, User, BaseUser, UserPreview]):
         """
         Remove a user their room moderator permissions.
 
         Args:
             user (Union[User, BaseUser, UserPreview]): The user from which his permissions should be taken.
         """
-        await self.__send("change_mod_status", dict(userId=user.id, value=False))
+        await self.__send("change_mod_status", dict(userId=user if isinstance(user, str) else user.id, value=False))
 
-    async def make_admin(self, user: Union[User, BaseUser, UserPreview]):
+    async def make_admin(self, user: Union[str, User, BaseUser, UserPreview]):
         """
         Make a user the room administrator/owner.
         NOTE: This action is irreversable.
@@ -465,9 +461,9 @@ class DogeClient(Repr):
         Args:
             user (Union[User, BaseUser, UserPreview]): The user which should be promoted to room admin.
         """
-        await self.__send("change_room_creator", dict(userId=user.id))
+        await self.__send("change_room_creator", dict(userId=user if isinstance(user, str) else user.id))
 
-    async def set_listener(self, user: Union[User, BaseUser, UserPreview] = None):
+    async def set_listener(self, user: Union[str, User, BaseUser, UserPreview] = None):
         """
         Force a user to be a listener.
 
@@ -476,9 +472,9 @@ class DogeClient(Repr):
         """
         if not user:
             user = self.user
-        await self.__send("set_listener", dict(userId=user.id))
+        await self.__send("set_listener", dict(userId=user if isinstance(user, str) else user.id))
 
-    async def ban_chat(self, user: Union[User, BaseUser, UserPreview]):
+    async def ban_chat(self, user: Union[str, User, BaseUser, UserPreview]):
         """
         Ban a user from speaking in the room.
         NOTE: This action can not be undone.
@@ -486,16 +482,16 @@ class DogeClient(Repr):
         Args:
             user (Union[User, BaseUser, UserPreview]): The user from which their chat permissions should be taken.
         """
-        await self.__send("ban_from_room_chat", dict(userId=user.id))
+        await self.__send("ban_from_room_chat", dict(userId=user if isinstance(user, str) else user.id))
 
-    async def ban(self, user: Union[User, BaseUser, UserPreview]):
+    async def ban(self, user: Union[str, User, BaseUser, UserPreview]):
         """
         Bans a user from a room.
 
         Args:
             user (Union[User, BaseUser, UserPreview]): The user who should be banned.
         """
-        await self.__send("block_from_room", dict(userId=user.id))
+        await self.__send("block_from_room", dict(userId=user if isinstance(user, str) else user.id))
 
     async def unban(self, user: Union[User, BaseUser, UserPreview]):
         """
@@ -506,14 +502,14 @@ class DogeClient(Repr):
         """
         await self.__send("unban_from_room", dict(userId=user.id), fetch_id=uuid4())
 
-    async def add_speaker(self, user: Union[User, BaseUser, UserPreview]):
+    async def add_speaker(self, user: Union[str, User, BaseUser, UserPreview]):
         """
         Accept a speaker request from a user.
 
         Args:
             user (Union[User, BaseUser, UserPreview]): The user who will has to be accepted.
         """
-        await self.__send("add_speaker", dict(userId=user.id))
+        await self.__send("add_speaker", dict(userId=user if isinstance(user, str) else user.id))
 
     async def delete_message(self, id: str, user_id: str):
         """
